$set 3 #Configmenu

$ #ConfigOptions
# Instllningar
$ #FocusModel
# Fokusmodell
$ #WindowPlacement
# Fnsterplacering
$ #ImageDithering
# Bilddithering
$ #OpaqueMove
# Ogenomskinlig fnsterfrflyttning
$ #FullMax
# Full maximering
$ #FocusNew
# Fokus p nya fnster
$ #FocusLast
# Fokusera fnster vid skrivbordsbyte
$ #DisableBindings
# Gr s att bindningar inte fungerar med Scroll Lock
$ #ClickToFocus
# Klicka fr fokus
$ #SloppyFocus
# Hafsig fokus
$ #AutoRaise
# Hj automatiskt
$ #ClickRaise
# Klicka fr att hja
$ #SmartRows
# Smart placering (Rader)
$ #SmartCols
# Smart placering (Kolumner)
$ #Cascade
# Kaskadplacering
$ #LeftRight
# Frn vnster
$ #RightLeft
# Frn hger
$ #TopBottom
# Uppifrn
$ #BottomTop
# Nerifrn
$ #NoDithering
# Do not dither images
$ #OrderedDithering
# Use fast dither
$ #FloydSteinbergDithering
# Use high-quality dither
